# unitorch.cli.models.blip

## BlipProcessor

!!! tip
    **`core/process/blip`** is the section for configuration of BlipProcessor.

::: unitorch.cli.models.blip.BlipProcessor

## BlipForPretrain

!!! tip
    **`core/model/pretrain/blip`** is the section for configuration of BlipForPretrain.

::: unitorch.cli.models.blip.BlipForPretrain

## BlipForClassification

!!! tip
    **`core/model/classification/blip`** is the section for configuration of BlipForClassification.

::: unitorch.cli.models.blip.BlipForClassification

## BlipForTextClassification

!!! tip
    **`core/model/classification/blip/text`** is the section for configuration of BlipForTextClassification.

::: unitorch.cli.models.blip.BlipForTextClassification

## BlipForImageClassification

!!! tip
    **`core/model/classification/blip/image`** is the section for configuration of BlipForImageClassification.

::: unitorch.cli.models.blip.BlipForImageClassification

## BlipForImageCaption

!!! tip
    **`core/model/caption/blip`** is the section for configuration of BlipForImageCaption.

::: unitorch.cli.models.blip.BlipForImageCaption
